==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/content/kinetics/gauge/GaugeRenderer.java <==
package com.zurrtum.create.client.content.kinetics.gauge;

import com.zurrtum.create.catnip.data.Iterate;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.catnip.render.CachedBuffers;
import com.zurrtum.create.client.catnip.render.SuperByteBuffer;
import com.zurrtum.create.client.content.kinetics.base.ShaftRenderer;
import com.zurrtum.create.client.flywheel.lib.model.baked.PartialModel;
import com.zurrtum.create.content.kinetics.gauge.GaugeBlock;
import com.zurrtum.create.content.kinetics.gauge.GaugeBlock.Type;
import com.zurrtum.create.content.kinetics.gauge.GaugeBlockEntity;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_11683;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5614;

public class GaugeRenderer extends ShaftRenderer<GaugeBlockEntity, GaugeRenderer.GaugeRenderState> {
    protected Type type;

    public static GaugeRenderer speed(class_5614.class_5615 context) {
        return new GaugeRenderer(context, Type.SPEED);
    }

    public static GaugeRenderer stress(class_5614.class_5615 context) {
        return new GaugeRenderer(context, Type.STRESS);
    }

    protected GaugeRenderer(class_5614.class_5615 context, Type type) {
        super(context);
        this.type = type;
    }

    @Override
    public GaugeRenderState createRenderState() {
        return new GaugeRenderState();
    }

    @Override
    public void updateRenderState(
        GaugeBlockEntity be,
        GaugeRenderState state,
        float tickProgress,
        class_243 cameraPos,
        @Nullable class_11683.class_11792 crumblingOverlay
    ) {
        super.updateRenderState(be, state, tickProgress, cameraPos, crumblingOverlay);
        if (state.support) {
            return;
        }
        class_2680 gaugeState = be.method_11010();
        GaugeBlock block = (GaugeBlock) gaugeState.method_26204();
        class_1937 world = be.method_10997();
        List<class_2350> facings = new ArrayList<>();
        for (class_2350 facing : Iterate.directions) {
            if (block.shouldRenderHeadOnFace(world, state.pos, gaugeState, facing)) {
                facings.add(facing);
            }
        }
        if (facings.isEmpty()) {
            return;
        }
        int size = facings.size();
        float[] angles = new float[size];
        for (int i = 0; i < size; i++) {
            angles[i] = (float) ((-facings.get(i).method_10144() - 90) / 180 * Math.PI);
        }
        state.angles = angles;
        PartialModel partialModel = (type == Type.SPEED ? AllPartialModels.GAUGE_HEAD_SPEED : AllPartialModels.GAUGE_HEAD_STRESS);
        state.head = CachedBuffers.partial(partialModel, gaugeState);
        state.dial = CachedBuffers.partial(AllPartialModels.GAUGE_DIAL, gaugeState);
        state.dialPivot = 5.75f / 16;
        float progress = class_3532.method_16439(tickProgress, be.prevDialState, be.dialState);
        state.rotate = (float) (Math.PI / 2 * -progress);
    }

    public static class GaugeRenderState extends KineticRenderState {
        public float[] angles;
        public SuperByteBuffer head;
        public SuperByteBuffer dial;
        public float dialPivot;
        public float rotate;

        @Override
        public void render(class_4587.class_4665 matricesEntry, class_4588 vertexConsumer) {
            super.render(matricesEntry, vertexConsumer);
            if (angles != null) {
                for (float angle : angles) {
                    dial.rotateCentered(angle, class_2350.field_11036).translate(0, dialPivot, dialPivot).rotate(rotate, class_2350.field_11034)
                        .translate(0, -dialPivot, -dialPivot).light(lightmapCoordinates).renderInto(matricesEntry, vertexConsumer);
                    head.rotateCentered(angle, class_2350.field_11036).light(lightmapCoordinates).renderInto(matricesEntry, vertexConsumer);
                }
            }
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/content/kinetics/gauge/GaugeRenderer.java <==
package com.zurrtum.create.client.content.kinetics.gauge;

import com.zurrtum.create.catnip.data.Iterate;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.catnip.render.CachedBuffers;
import com.zurrtum.create.client.catnip.render.SuperByteBuffer;
import com.zurrtum.create.client.content.kinetics.base.ShaftRenderer;
import com.zurrtum.create.client.flywheel.lib.model.baked.PartialModel;
import com.zurrtum.create.content.kinetics.gauge.GaugeBlock;
import com.zurrtum.create.content.kinetics.gauge.GaugeBlock.Type;
import com.zurrtum.create.content.kinetics.gauge.GaugeBlockEntity;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_11683;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5614;

public class GaugeRenderer extends ShaftRenderer<GaugeBlockEntity, GaugeRenderer.GaugeRenderState> {
    protected Type type;

    public static GaugeRenderer speed(class_5614.class_5615 context) {
        return new GaugeRenderer(context, Type.SPEED);
    }

    public static GaugeRenderer stress(class_5614.class_5615 context) {
        return new GaugeRenderer(context, Type.STRESS);
    }

    protected GaugeRenderer(class_5614.class_5615 context, Type type) {
        super(context);
        this.type = type;
    }

    @Override
    public GaugeRenderState createRenderState() {
        return new GaugeRenderState();
    }

    @Override
    public void extractRenderState(
        GaugeBlockEntity be,
        GaugeRenderState state,
        float tickProgress,
        class_243 cameraPos,
        @Nullable class_11683.class_11792 crumblingOverlay
    ) {
        super.extractRenderState(be, state, tickProgress, cameraPos, crumblingOverlay);
        if (state.support) {
            return;
        }
        class_2680 gaugeState = be.method_11010();
        GaugeBlock block = (GaugeBlock) gaugeState.method_26204();
        class_1937 world = be.method_10997();
        List<class_2350> facings = new ArrayList<>();
        for (class_2350 facing : Iterate.directions) {
            if (block.shouldRenderHeadOnFace(world, state.blockPos, gaugeState, facing)) {
                facings.add(facing);
            }
        }
        if (facings.isEmpty()) {
            return;
        }
        int size = facings.size();
        float[] angles = new float[size];
        for (int i = 0; i < size; i++) {
            angles[i] = (float) ((-facings.get(i).method_10144() - 90) / 180 * Math.PI);
        }
        state.angles = angles;
        PartialModel partialModel = (type == Type.SPEED ? AllPartialModels.GAUGE_HEAD_SPEED : AllPartialModels.GAUGE_HEAD_STRESS);
        state.head = CachedBuffers.partial(partialModel, gaugeState);
        state.dial = CachedBuffers.partial(AllPartialModels.GAUGE_DIAL, gaugeState);
        state.dialPivot = 5.75f / 16;
        float progress = class_3532.method_16439(tickProgress, be.prevDialState, be.dialState);
        state.rotate = (float) (Math.PI / 2 * -progress);
    }

    public static class GaugeRenderState extends KineticRenderState {
        public float[] angles;
        public SuperByteBuffer head;
        public SuperByteBuffer dial;
        public float dialPivot;
        public float rotate;

        @Override
        public void render(class_4587.class_4665 matricesEntry, class_4588 vertexConsumer) {
            super.render(matricesEntry, vertexConsumer);
            if (angles != null) {
                for (float angle : angles) {
                    dial.rotateCentered(angle, class_2350.field_11036).translate(0, dialPivot, dialPivot).rotate(rotate, class_2350.field_11034)
                        .translate(0, -dialPivot, -dialPivot).light(lightCoords).renderInto(matricesEntry, vertexConsumer);
                    head.rotateCentered(angle, class_2350.field_11036).light(lightCoords).renderInto(matricesEntry, vertexConsumer);
                }
            }
        }
    }
}
